pub struct PublicKey<T, const N: usize>(pub(crate) [u8; N], pub(crate) PhantomData<T>);Expand description
A public key base type
Tuple Fields
0: [u8; N]1: PhantomData<T>Implementations
Sourceimpl PublicKey<Ecdsa, UNCOMPRESSED_PUB_KEY_SIZE>
impl PublicKey<Ecdsa, UNCOMPRESSED_PUB_KEY_SIZE>
Sourcepub const COMPRESSED_SIZE: usize = 33usize
pub const COMPRESSED_SIZE: usize = 33usize
The size of a compressed ECDSA public key in bytes.
Sourcepub fn uncompressed(&self) -> [u8; 65]
pub fn uncompressed(&self) -> [u8; 65]
Returns the uncompressed public key as a byte array.
Sourcepub fn compressed(&self) -> [u8; 33]
pub fn compressed(&self) -> [u8; 33]
Returns the compressed public key as a byte array.